//
//  Cyborn OS - Copyright (C) 2004 Steve Gotthardt - Gotthardt Designs
//
//  This file is part of the Cyborn distribution.
//
//  Cyborn is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Cyborn is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with Cyborn; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  A special exception to the GPL can be applied should you wish to distribute
//  a combined work that includes Cyborn, without being obliged to provide
//  the source code for any proprietary components.
//

#include "lcd.h"
#include "gfx.h"
#include "lowlevel.h"



#define DELAY_COUNT 0x2000


// make a surface to put everything on
#define BG_COLS 20
#define BG_ROWS 100
static unsigned char bg[BG_COLS * BG_ROWS];

static SurfaceT surface =
{
    0xFF, 0,  // fore and background
    BG_COLS,
    BG_ROWS,
    bg
};


void
delay(unsigned long delay)
{
    volatile unsigned long counter = delay;

    while (counter--);
}


int
main(int argc, char *argv[])
{
    GfxPT y1, x1;


    for (;;)
    {
        SurfaceBackground(&surface, 0x04);
        SurfaceClear(&surface);

        for (x1 = 0, y1 = 0; y1 < 45; y1 +=2, x1++)
        {
            // horizontal lines - x1, y1, x2
            SurfaceForeground(&surface, GFX_COLOR_BLK);
            GfxHLine(&surface, x1, y1, x1 + 21);
            GfxHLine(&surface, x1, y1+50, x1 + y1/2);

            SurfaceForeground(&surface, GFX_COLOR_WHT);
            GfxHLine(&surface, x1+ 15, y1, x1 + 28);
            GfxHLine(&surface, x1+15, y1+50, x1 + 16+ y1/2);

            SurfaceForeground(&surface, GFX_COLOR_DKG);
            GfxHLine(&surface, x1+30, y1+1, x1 + 44);
            GfxHLine(&surface, x1+30, y1+51, x1+30 + y1/2);

            SurfaceForeground(&surface, GFX_COLOR_LTG);
            GfxHLine(&surface, x1+35, y1, x1 + 55);
            GfxHLine(&surface, x1+36, y1+53, x1 +36+ y1/2);

            //SurfaceForeground(&surface, GFX_COLOR_BLK);
            //GfxCircle(&surface, x1 * 2, y1*2, x1 /2);

        }


        // now display the surface at col0 row0
        SurfaceDisplay(&surface, 0, 0);


        SurfaceBackground(&surface, 0x00);
        SurfaceClear(&surface);

        {
            unsigned key;
            static unsigned radius = 5;

            SurfaceForeground(&surface, GFX_COLOR_BLK);
            GfxCircle(&surface, 40, 50, radius);

            key = _rawkey();
            if (key)
            {
                switch (key)
                {
                    case RAW_KEY_AD: if (radius > 4) radius--; break;
                    case RAW_KEY_AU: if (radius <39) radius++; break;
                    //case RAW_KEY_SPACE: shadow = (shadow != 1) ;
                }
                delay(0x200);
            }


        }


        // now display the surface at col0 row0
        SurfaceDisplay(&surface, 20, 0);



        delay(DELAY_COUNT);  //

    }

    return 0;
}



